//why bother making a main?  I'm too smart for that..

void talk( void)
{
say_stop("`%Private property! Keep out! - Wizard Martridge", &current_sprite);
wait(500);
say("How interesting.  I wonder what is hidden around here...",1);
}
