void talk( void )
{
 if (&s4-duck < 2)
   {
    say("`%Duck Worship Center", &current_sprite);
   return;
   }

    say_stop("`%Dink Worship Center", &current_sprite);
    say("It sure is easy to be deified these days.", 1);

}
