void main( void )
{
int &mx = sp_x(1, -1);
int &my = sp_y(1, -1);


if (&old_womans_duck == 1)
 {
 int &hiding;
 &hiding = random(4, 1);
 Debug("random is &hiding");
  if (&hiding == 1)
  {
    &vision = 2;
    say("There's that duck!!", 1); 
  }
  else
  {
  if (random(3,1) == 1)
   say("Where could Ethel's duck be?", 1);
  }
 }
}
 