
void main(void)
{

}

void talk(void)
{
 if (&story >= 3)
 {
 say("Mom's bed is on fire, noooo!", 1);
 return;
 }
 say("Mom's bed.", 1);
}

void hit(void)
{
 if (&story >= 3)
 {
 say("No it's too hot.", 1);
 return;
 }
 say("Eat this, bed!", 1);
}

