void main( void )
{
}
void hit( void )
{
 say("'Sign' me up.. for DESTRUCTION! Haw haw!", 1);
}

void talk( void )
{
if (&story < 8)
  {
 say("`%KernSin is closed until preparation is complete.", &current_sprite);
 wait(1000);
 say("Huh?  What on earth can they be preparing?", 1);
  return;
  }
if (&story > 7)
  {
 say("`%KernSin city limits.  Please enter our lovely town!", &current_sprite);
  }
}
