void main( void )
{

//playmidi("neighbor.mid");

 if (&farmer_quest > 1)
 {
 &vision = 1; 
 //so the real warping ladder will appear
 }

 int &m;
 &m = random(3,1);
 if (&m == 1)
 {
 say("Ah, hello Mr. SmileStein.", 1);
 }
}
