void main ( void )
{
   wait(2000);
   say_stop("I've come to get my meat", 1);
   wait(500);
   say_stop("I've come to get my meat", 1);
   wait(500);
   say_stop("I've come to get my meat", 1);
   wait(500);
   say_stop("I've come to get my meat", 1);
   wait(500);
   say_stop("I've come to get my meat", 1);
   wait(500);
   say_stop("I've come to get my meat", 1);
   wait(500);
   say_stop("I've come to get my meat", 1);
   wait(500);
   say_stop("I've come to get my meat", 1);
}
