void main( void )
{
 int &sporty_spice;
 int &naughty_spice;
 int &exotic_spice;
 int &sweet_spice;
 int &nice_spice;
}

void talk( void )
{
 say_stop("Oh my god, it's you!!!", 1);
 say_stop("`2Hello there guy, what's your name?", &sporty_spice);
 say_stop("Uhh ...", 1);
 wait(250);
 say_stop("Let's not discuss that now Sporty.  Let's talk about you ..", 1);
 say_stop("all five of you and me!!", 1);
}

void 2become1( void )
{
 When two become one.
 I need some love like I never needed love before
 wanna make love to you baby
 I had a little love now I'm back for more
 wanna make love to ya baby

 (solo)

 be a little bit wiser baby
 put it on, put it on
 cause tonight, is the night where two become one

 Set your spirit free, it's the only way to be
 it's the only way to be
 it's the only way to be
}

void wannabe( void )
{
}
 