void main( void )
{
 sp_touch_damage(&current_sprite, -1);
//will run touch if touched now
}

void touch( void)
{
say("`2Please sir, the only food we have is down there!", &temp4hold);
move_stop(1, 6, 240, 1);
move_stop(1, 2, 170, 1);
}
