void main( void )
{
 if (&gobpass > 0)
   {
    //let's open the gates for them

    //let all sprites be drawn first
    wait(1);

       int &dumb = sp(3);
        sp_hard(&dumb, 1);
        draw_hard_sprite(&dumb);
        sp_active(&dumb, 0);

   }
}
