void main( void )
{
 if (&s2-aunt == 1)
   {
  &s2-aunt = 2;
    say_stop("Not a bad little room.  I think I'm going to enjoy my stay.", 1);
    wait(500);
    say_stop("Except for that guy Jack...", 1);
   }

}
