//script for aunts house

void main( void )
{
 //build aunt
 int &crap = create_sprite(290,250, 0, 0, 0);
 &temp2hold = &crap;
 sp_script(&crap, "s2-nadp");

if (&s2-nad > 2)
              {
         //build little girl
         int &crap = create_sprite(390,210, 0, 0, 0);
         sp_script(&crap, "s2-qgirl");
               }

}



