void main( void )
{

}
void talk( void)
{
freeze(1);
if (&story < 8)
  {
  say_stop("`%The King's News, issue 43.", &current_sprite);
  wait(300);
  say_stop("`%A young man by the name of Milder Flatstomp has won the King's", &current_sprite);
  wait(300);
  say_stop("`%jousting tournament.", &current_sprite);
  wait(300);
  say_stop("What?!  Whatever!", &current_sprite);

   unfreeze(1);
    return;
   }

if (&story == 8)
  {
  say_stop("`%The King's News, issue 44.", &current_sprite);
  wait(300);
  say_stop("`%Milder Flatstomp is knighted by King Daniel for his part in uncovering", &current_sprite);
  wait(300);
  say_stop("`%a Cast plot!", &current_sprite);
  wait(300);
  say_stop("`%Also in the news:  A pig farmer named Dink Smallwood found a lost Terris girl.", &current_sprite);
  wait(300);
  say_stop("Pig farmer!? What a crock.  At least I'm on there though.", &current_sprite);
  wait(300);
  say_stop("`% Also:  The town of Kernsin is having a festival, all invited.", &current_sprite);

unfreeze(1);
   return;

   }

if (&story == 9)
  {
  say_stop("`%The King's News, issue 45.", &current_sprite);
  wait(300);
  say_stop("`%The famous Knight Milder Flatstomp has wed!", &current_sprite);
  wait(300);
  say_stop("Flatstomp got married?  Wow, small world.", &current_sprite);
  wait(300);
  say_stop("`%King Daniel wishes Milder and Lyna (the lucky maiden) well.", &current_sprite);
  wait(300);
  say_stop("LYNA? NOOO!!!", &current_sprite);
  wait(300);
  say_stop("`% Also:  The town of KernSin is having a parade today.", &current_sprite);
   unfreeze(1);
   return;
   }

if (&story == 10)
  {
  say_stop("`%The King's News, issue 46.", &current_sprite);
  wait(300);
  say_stop("`%Dink Smallwood saves KernSin and foils the Cast!", &current_sprite);
  wait(300);
  say_stop("Yeah!!!!!", &current_sprite);
  wait(300);
  say_stop("`%Also in the news:  Windemere Village experiences a famine.", &current_sprite);
  wait(300);
   unfreeze(1);
   return;
   }


if (&story == 11)
  {
  say_stop("`%The King's News, issue 47.", &current_sprite);
  wait(300);
  say_stop("`%The Knight Milder Flatstomp ventures into The Darklands - hunting the Cast.", &current_sprite);
  wait(300);
  say_stop("Big freakin' deal.", &current_sprite);
  wait(300);
  say_stop("`% Also:  Hero Smallwood saves Windemere Village from famine!  He reportly", &current_sprite);
  wait(300);
  say_stop("`%taught them proper agricultural procedure he learned pig farming in Stonebrook.", &current_sprite);
  wait(300);
  say_stop("Arg! Oh well, close enough.", &current_sprite);
   unfreeze(1);
   return;
   }

if (&story == 12)
  {
  say_stop("`%The King's News, issue 48.", &current_sprite);
  wait(300);
  say_stop("`%Sir Flatstomp is declared missing in the Darklands!", &current_sprite);
  wait(300);
  say_stop("`%'Tis a sad day for our country' - King Daniel", &current_sprite);
  wait(300);
  say_stop("Wow.. Poor Milder...he really wasn't such a bad guy.", &current_sprite);
   unfreeze(1);
   return;
   }

if (&story == 13)
  {
  say_stop("`%The King's News, issue 48.", &current_sprite);
  wait(300);
  say_stop("`%Sir Flatstomp is declared missing in the Darklands!", &current_sprite);
  wait(300);
  say_stop("`%'Tis a sad day for our country' - King Daniel", &current_sprite);
  wait(300);
  say_stop("Wow.. Poor Milder...he really wasn't such a bad guy.", &current_sprite);
   unfreeze(1);
   return;
   }

if (&story == 14)
  {
  say_stop("`%The King's News, issue 49.", &current_sprite);
  wait(300);
  say_stop("`%King Daniel sends Dink Smallwood to rescue Sir Milder!", &current_sprite);
  wait(300);
  say_stop("`%'Smallwood is brave, I'll give him that.' - King Daniel", &current_sprite);
   unfreeze(1);
   return;
   }


if (&story == 15)
  {
  say_stop("`%The King's News, issue 50.", &current_sprite);
  wait(300);
  say_stop("`%Smallwood has returned from the Darklands!", &current_sprite);
  wait(300);
  say_stop("`%'I can't wait until he gets to the castle!' - King Daniel", &current_sprite);
   unfreeze(1);
   return;
   }

if (&story == 16)
  {
  say_stop("`%The King's News, issue 51.", &current_sprite);
  wait(300);
  say_stop("`%Smallwood for King!  Read all about it!", &current_sprite);
  wait(300);
  say_stop("`%'You've won the game, please don't take my throne too!' - King Daniel", &current_sprite);
   unfreeze(1);
   return;
   }


  say_stop("`%The King's News, issue 76.", &current_sprite);
  wait(300);
  say_stop("`%No news to report.", &current_sprite);
unfreeze(1);


}
  
