void main( void )
{
if (&s5-jop == 1)
{
    //create guy
    &temp1hold = create_sprite(330, 290, 0, 0, 0);
    sp_script(&temp1hold, "s5-guy");

    //create mom
    &temp2hold = create_sprite(115, 160, 0, 0, 0);
    sp_script(&temp2hold, "s5-mom");
 }



}

