
void main(void)
{
}

void talk(void)
{
 int &maybe;
 &maybe = random(3,1);
   if (&maybe == 1)
   {
   say("Libby's bed, ahh yeah.", 1);
   {
   if (&maybe == 2)
   {
   say("Libby's bed, to dream the impossible dream...", 1);
   }
   if (&maybe == 3)
   {
   say("Libby's bed, looks lonely.", 1);
   }
}

void hit(void)
{
 say("Get ready for me!", 1);
}

