//slayer statue

void talk (void)
{
say("`6It's a stuffed slayer.  We pay good money for slayer claws here.",&temphold);

}

void hit(void)
{
say("`6Um, sir?  It's stuffed.  It isn't alive... It won't hurt you.", &temphold);
}

