void main( void )
{
}

void talk( void )
{
 if (&story < 10)
 {
  say("`%To Windemere Village      Note:  Bridge Out", &current_sprite);
  return;
 }
 say("`%To Windemere Village", &current_sprite);
}
