void main( void )
{
 if (&farmer_quest == 2)
 {
		int &bot1;
		int &bot2;
		int &bot3;
		int &bot4;
		&bot1 = sp(17);
		&bot2 = sp(18);
		&bot3 = sp(19);
		&bot4 = sp(20);
		sp_active(&bot1, 0);
		sp_active(&bot2, 0);		
		sp_active(&bot3, 0);
		sp_active(&bot4, 0);
 }
}