void talk( void )
{
 say_stop("`%Wanted - Any info on the rogue group known as The Cast.", &current_sprite);
 say_stop("`%Contact King Daniel at Goodheart Castle for possible reward.", &current_sprite);

}
