void main( void )
{
if (&caveguy > 4)
  {
int &mcrap = sp(22);
sp_hard(&mcrap, 1);
draw_hard_sprite(&mcrap);
sp_active(&mcrap, 0);


  }

}

void push( void )
{
 say("Uh, darn thing won't budge!!", 1);
}
