void main( void )
{
}

void talk( void )
{
if (&story > 10)
  {
  say_stop("`%Super-Fry Chicken opening soon.", &current_sprite);
  return;
  }

 freeze(1);
 say_stop("`%Hear ye, hear ye ...", &current_sprite);
 say_stop("`%By order of our great ducks the monthly tax shall be doubled.", &current_sprite);
 say_stop("`%This also applies to food donations.", &current_sprite);
 say_stop("`%Long live the ducks.", &current_sprite;
 unfreeze(1);
}
