void main ( void )
{
}

void talk ( void )
{
say("I knew you'd come back.", 1);
}

void die ( void )
{
 int &who = sp(23);
 &old_womans_duck = 5;
 freeze(1);
 wait(500);
 say_stop("`3Dink, noooooooo!!!", &who);
 wait(250);
 say_stop("`3You little bastard!!", &who);
 wait(250);
 say_stop("`3Get out!!", &who);
 wait(250);
 say_stop("Uh, sorry.", 1);
 unfreeze(1);
}
