
void main(void)
{
}

void talk(void)
{
 if (&story >= 3)
 {
 say("My bed is going to burn up!", 1);
 return;
 }
 say("This is my bed.  So clean and neat!  Mom must have made it.", 1);
}

void hit(void)
{
 if (&story >= 3)
 {
 say("It's hot!", 1);
 return;
 }
 say("Die, stupid bed!", 1);
}

 
